@@ -670,6 +670,24 @@ class PruneOptional(OptionsBase):
         super().__init__(**kwargs)
 
 
+@dataclass
+class CompactOptional(OptionsBase):
+    """Compact command options
+
+    :param cleanup_commits: cleanup commit-only 17-byte segment files
+    :type cleanup_commits: bool
+    :param threshold: set minimum threshold for saved space in PERCENT (Default: 10)
+    :type threshold: int
+    """
+
+    cleanup_commits: bool = False
+    threshold: int = 10
+
+    # pylint: disable=useless-super-delegation
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+
+
 @dataclass
 class InfoOptional(OptionsBase):
     """Info command options
@@ -851,6 +869,7 @@ class CommandOptions:
         "diff": DiffOptional,
         "delete": DeleteOptional,
         "prune": PruneOptional,
+        "compact": CompactOptional,
         "info": InfoOptional,
         "mount": MountOptional,
         "key_export": KeyExportOptional,
